==> jc-1.4.0.tar.gz: soot/util/queue/ChunkedQueue.h <==
// public final class soot.util.queue.ChunkedQueue

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e0a17cfc325c0311 soot_util_queue_ChunkedQueue

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_queue_ChunkedQueue_H_
#define _JC_soot_util_queue_ChunkedQueue_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_queue_QueueReader$object;

// Typedefs
typedef struct _jc_soot_util_queue_ChunkedQueue$sub_refs	_jc_soot_util_queue_ChunkedQueue$sub_refs;
typedef struct _jc_soot_util_queue_ChunkedQueue$sub_nonrefs	_jc_soot_util_queue_ChunkedQueue$sub_nonrefs;
typedef struct _jc_soot_util_queue_ChunkedQueue$refs	_jc_soot_util_queue_ChunkedQueue$refs;
typedef struct _jc_soot_util_queue_ChunkedQueue$nonrefs	_jc_soot_util_queue_ChunkedQueue$nonrefs;
typedef struct _jc_soot_util_queue_ChunkedQueue$object	_jc_soot_util_queue_ChunkedQueue$object;

typedef struct _jc_soot_util_queue_ChunkedQueue$fields_struct	_jc_soot_util_queue_ChunkedQueue$fields_struct;
typedef const struct _jc_soot_util_queue_ChunkedQueue$vmethods	_jc_soot_util_queue_ChunkedQueue$vmethods;
typedef const struct _jc_soot_util_queue_ChunkedQueue$vtable	_jc_soot_util_queue_ChunkedQueue$vtable;
typedef const struct _jc_soot_util_queue_ChunkedQueue$vtype	_jc_soot_util_queue_ChunkedQueue$vtype;

// Class fields structure
struct _jc_soot_util_queue_ChunkedQueue$fields_struct {
	jint	LENGTH;
};
extern _jc_soot_util_queue_ChunkedQueue$fields_struct _jc_soot_util_queue_ChunkedQueue$class_fields;

// Constructors
extern void _jc_soot_util_queue_ChunkedQueue$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_queue_ChunkedQueue$object *);

// Virtual methods
extern void _jc_soot_util_queue_ChunkedQueue$method$add$75d6bd5079bf5583(_jc_env *, struct _jc_soot_util_queue_ChunkedQueue$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_util_queue_QueueReader$object *_jc_soot_util_queue_ChunkedQueue$method$reader$57a27ba9564050c3(_jc_env *, struct _jc_soot_util_queue_ChunkedQueue$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_queue_ChunkedQueue$method_info$add$75d6bd5079bf5583;
extern _jc_method _jc_soot_util_queue_ChunkedQueue$method_info$reader$57a27ba9564050c3;

// Virtual methods structure
struct _jc_soot_util_queue_ChunkedQueue$vmethods {
	void	(*add$75d6bd5079bf5583)(_jc_env *, struct _jc_soot_util_queue_ChunkedQueue$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_util_queue_QueueReader$object	*(*reader$57a27ba9564050c3)(_jc_env *, struct _jc_soot_util_queue_ChunkedQueue$object *);
};

// Vtable
struct _jc_soot_util_queue_ChunkedQueue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_queue_ChunkedQueue$vmethods	soot_util_queue_ChunkedQueue;
};

// Vtype
struct _jc_soot_util_queue_ChunkedQueue$vtype {
	_jc_type			type;
	_jc_soot_util_queue_ChunkedQueue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_queue_ChunkedQueue$sub_refs {
	_jc_object_array	*q;
};

// Reference instance fields (object)
struct _jc_soot_util_queue_ChunkedQueue$refs {
    _jc_soot_util_queue_ChunkedQueue$sub_refs	soot_util_queue_ChunkedQueue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_queue_ChunkedQueue$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_soot_util_queue_ChunkedQueue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_queue_ChunkedQueue$sub_nonrefs	soot_util_queue_ChunkedQueue;
};

// Object instance structure
struct _jc_soot_util_queue_ChunkedQueue$object {
	_jc_soot_util_queue_ChunkedQueue$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_queue_ChunkedQueue$vtype	*vtype;
	_jc_soot_util_queue_ChunkedQueue$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_queue_ChunkedQueue$vtype _jc_soot_util_queue_ChunkedQueue$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_queue_ChunkedQueue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_queue_ChunkedQueue$class_object;

#endif	/* _JC_soot_util_queue_ChunkedQueue_H_ */

==> jc-1.4.6.tar.gz: soot/util/queue/ChunkedQueue.h <==
// public final class soot.util.queue.ChunkedQueue

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e0a17cfc325c0311 soot_util_queue_ChunkedQueue

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_queue_ChunkedQueue_H_
#define _JC_soot_util_queue_ChunkedQueue_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_queue_QueueReader$object;

// Typedefs
typedef struct _jc_soot_util_queue_ChunkedQueue$sub_refs	_jc_soot_util_queue_ChunkedQueue$sub_refs;
typedef struct _jc_soot_util_queue_ChunkedQueue$sub_nonrefs	_jc_soot_util_queue_ChunkedQueue$sub_nonrefs;
typedef struct _jc_soot_util_queue_ChunkedQueue$refs	_jc_soot_util_queue_ChunkedQueue$refs;
typedef struct _jc_soot_util_queue_ChunkedQueue$nonrefs	_jc_soot_util_queue_ChunkedQueue$nonrefs;
typedef struct _jc_soot_util_queue_ChunkedQueue$object	_jc_soot_util_queue_ChunkedQueue$object;

typedef struct _jc_soot_util_queue_ChunkedQueue$fields_struct	_jc_soot_util_queue_ChunkedQueue$fields_struct;
typedef const struct _jc_soot_util_queue_ChunkedQueue$vmethods	_jc_soot_util_queue_ChunkedQueue$vmethods;
typedef const struct _jc_soot_util_queue_ChunkedQueue$vtable	_jc_soot_util_queue_ChunkedQueue$vtable;
typedef const struct _jc_soot_util_queue_ChunkedQueue$vtype	_jc_soot_util_queue_ChunkedQueue$vtype;

// Class fields structure
struct _jc_soot_util_queue_ChunkedQueue$fields_struct {
	jint	LENGTH;
};
extern _jc_soot_util_queue_ChunkedQueue$fields_struct _jc_soot_util_queue_ChunkedQueue$class_fields;

// Constructors
extern void _jc_soot_util_queue_ChunkedQueue$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_queue_ChunkedQueue$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_util_queue_ChunkedQueue$method$add$75d6bd5079bf5583(_jc_env *, struct _jc_soot_util_queue_ChunkedQueue$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_queue_QueueReader$object *_jc_soot_util_queue_ChunkedQueue$method$reader$57a27ba9564050c3(_jc_env *, struct _jc_soot_util_queue_ChunkedQueue$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_queue_ChunkedQueue$method_info$add$75d6bd5079bf5583;
extern _jc_method _jc_soot_util_queue_ChunkedQueue$method_info$reader$57a27ba9564050c3;

// Virtual methods structure
struct _jc_soot_util_queue_ChunkedQueue$vmethods {
	void	(*add$75d6bd5079bf5583)(_jc_env *, struct _jc_soot_util_queue_ChunkedQueue$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_queue_QueueReader$object	*(*reader$57a27ba9564050c3)(_jc_env *, struct _jc_soot_util_queue_ChunkedQueue$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_queue_ChunkedQueue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_queue_ChunkedQueue$vmethods	soot_util_queue_ChunkedQueue;
};

// Vtype
struct _jc_soot_util_queue_ChunkedQueue$vtype {
	_jc_type			type;
	_jc_soot_util_queue_ChunkedQueue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_queue_ChunkedQueue$sub_refs {
	_jc_object_array	*q;
};

// Reference instance fields (object)
struct _jc_soot_util_queue_ChunkedQueue$refs {
    _jc_soot_util_queue_ChunkedQueue$sub_refs	soot_util_queue_ChunkedQueue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_queue_ChunkedQueue$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_soot_util_queue_ChunkedQueue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_queue_ChunkedQueue$sub_nonrefs	soot_util_queue_ChunkedQueue;
};

// Object instance structure
struct _jc_soot_util_queue_ChunkedQueue$object {
	_jc_soot_util_queue_ChunkedQueue$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_queue_ChunkedQueue$vtype	*vtype;
	_jc_soot_util_queue_ChunkedQueue$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_queue_ChunkedQueue$vtype _jc_soot_util_queue_ChunkedQueue$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_queue_ChunkedQueue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_queue_ChunkedQueue$class_object;

#endif	/* _JC_soot_util_queue_ChunkedQueue_H_ */
